@@ -4,15 +4,21 @@ use parent 'DTL::Fast::Expression::Operator::Binary';
 
 use DTL::Fast::Utils qw(as_bool);
 
+#@Override
 sub render
 {
     my( $self, $context ) = @_;
     
-    return $self->dispatch( # this is bad in or, cause second argument should be calculated only if first is false. But in our situation it doesn't matter
+    return $self->dispatch( 
         as_bool($self->{'a'}->render($context, 1))
-        , as_bool($self->{'b'}->render($context, 1))
         , $context 
     );
 }
 
+sub get_b
+{
+    my( $self, $context) = @_;
+    return as_bool($self->{'b'}->render($context, 1));
+}
+
 1;
\ No newline at end of file
