@@ -6,9 +6,9 @@ $DTL::Fast::OPS_HANDLERS{'<'} = __PACKAGE__;
 
 sub dispatch
 {
-    my( $self, $arg1, $arg2) = @_;
+    my( $self, $arg1, $arg2, $context) = @_;
     
-    return $self->SUPER::dispatch($arg2, $arg1);
+    return $self->SUPER::dispatch($arg2, $arg1, $context);
 }
 
 1;
\ No newline at end of file
