@@ -2,13 +2,14 @@ package DTL::Fast::Expression::Operator::Binary::Pow;
 use strict; use utf8; use warnings FATAL => 'all';
 use parent 'DTL::Fast::Expression::Operator::Binary';
 
-$DTL::Fast::Expression::Operator::KNOWN{'**'} = __PACKAGE__;
+$DTL::Fast::OPS_HANDLERS{'**'} = __PACKAGE__;
+$DTL::Fast::OPS_HANDLERS{'pow'} = __PACKAGE__;
 
 use Scalar::Util qw(looks_like_number);
 
 sub dispatch
 {
-    my( $self, $arg1, $arg2) = @_;
+    my( $self, $arg1, $arg2, $context) = @_;
     my ($arg1_type, $arg2_type) = (ref $arg1, ref $arg2);
     my $result = 0;
 
@@ -22,7 +23,16 @@ sub dispatch
     }
     else
     {
-        die "Don't know how to involute $arg1 ($arg1_type) to power of $arg2 ($arg2_type)";
+        die $self->get_render_error(
+            $context,
+            sprintf(
+                "don't know how to involute %s (%s) to power of %s (%s)"
+                , $arg1 // 'undef'
+                , $arg1_type || 'SCALAR'
+                , $arg2 // 'undef'
+                , $arg2_type || 'SCALAR'
+            )
+        );
     }
 
     return $result;
