@@ -10,7 +10,7 @@ sub filter
 {
     shift;  # self
     shift->{'safe'} = 1;    # filter_manager
-    return DTL::Fast::Utils::html_protect(shift);
+    return DTL::Fast::html_protect(shift);
 }
 
 1;
\ No newline at end of file
