@@ -11,12 +11,14 @@ sub parse_parameters
 {
     my $self = shift;
     
-    die "Parent template was not specified"
+    die $self->get_parse_error("parent template was not specified")
         if not $self->{'parameter'};
             
-    die sprintf("Multiple extends specified in the template:\n\%s\n\%s\n"
-        , $DTL::Fast::Template::CURRENT_TEMPLATE->{'extends'}->{'original'} // 'undef'
-        , $self->{'parameter'} // 'undef'
+    die $self->get_parse_error(
+        sprintf("Multiple extends specified in the template:\n\%s\n\%s\n"
+            , $DTL::Fast::Template::CURRENT_TEMPLATE->{'extends'}->{'original'} // 'undef'
+            , $self->{'parameter'} // 'undef'
+        )
     ) if $DTL::Fast::Template::CURRENT_TEMPLATE->{'extends'};
             
     $DTL::Fast::Template::CURRENT_TEMPLATE->{'extends'} = DTL::Fast::Variable->new($self->{'parameter'});
