@@ -2,17 +2,22 @@ package DTL::Fast::Text;
 use strict; use utf8; use warnings FATAL => 'all'; 
 
 use DTL::Fast::Template;
+use Scalar::Util qw/weaken/;
 
 sub new
 {
     my ($proto, $text ) = @_;
     $text //= '';
     
-    return bless {
+    my $self = bless {
         'texts' => [$text]
         , '_template' => $DTL::Fast::Template::CURRENT_TEMPLATE
         , '_template_line' => $DTL::Fast::Template::CURRENT_TEMPLATE_LINE
     }, $proto;
+
+    weaken $self->{'_template'};
+
+    return $self;
 }
 
 sub append
